/*
 * $Id: rb_edje_main.c 28 2004-07-08 18:35:51Z tilman $
 *
 * Copyright (C) 2004 Tilman Sauerbeck (tilman at code-monkey de)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <ruby.h>

#include <Edje.h>

#include "rb_edje_main.h"
#include "rb_edje.h"

#ifdef DEBUG
static VALUE m_init (VALUE self)
{
	return INT2FIX (edje_init ());
}

static VALUE m_shutdown (VALUE self)
{
	return INT2FIX (edje_shutdown ());
}
#endif

static VALUE m_freeze (VALUE self)
{
	edje_freeze ();

	return Qnil;
}

static VALUE m_thaw (VALUE self)
{
	edje_thaw ();

	return Qnil;
}

static VALUE m_frametime_get (VALUE self)
{
	return rb_float_new (edje_frametime_get ());
}

static VALUE m_frametime_set (VALUE self, VALUE val)
{
	Check_Type (val, T_FLOAT);

	edje_frametime_set (NUM2DBL (val));

	return Qnil;
}

void Init_edje (void)
{
	rb_require ("evas");

	mEdje = rb_define_module ("Edje");

#ifdef DEBUG
	rb_define_module_function (mEdje, "init", m_init, 0);
	rb_define_module_function (mEdje, "shutdown", m_shutdown, 0);
#endif

	rb_define_module_function (mEdje, "freeze", m_freeze, 0);
	rb_define_module_function (mEdje, "thaw", m_thaw, 0);
	rb_define_module_function (mEdje, "frametime", m_frametime_get, 0);
	rb_define_module_function (mEdje, "frametime=", m_frametime_set, 1);

	Init_Edje ();
}

